==> evolution-devel-3.18.5.2-1.tar.xz: usr/include/evolution/e-util/e-util-enumtypes.h <==

/* Generated data (by glib-mkenums) */

#ifndef E_UTIL_ENUMTYPES_H
#define E_UTIL_ENUMTYPES_H

#include <glib-object.h>

G_BEGIN_DECLS

/* Enumerations from "/usr/src/ports/evolution/evolution-3.18.5.2-1.x86_64/src/evolution-3.18.5.2/e-util/e-util-enums.h" */

#define E_TYPE_ACTIVITY_STATE	(e_activity_state_get_type())
GType e_activity_state_get_type	(void) G_GNUC_CONST;

#define E_TYPE_AUTOMATIC_ACTION_POLICY	(e_automatic_action_policy_get_type())
GType e_automatic_action_policy_get_type	(void) G_GNUC_CONST;

#define E_TYPE_DATE_WEEKDAY	(e_date_weekday_get_type())
GType e_date_weekday_get_type	(void) G_GNUC_CONST;

#define E_TYPE_DURATION_TYPE	(e_duration_type_get_type())
GType e_duration_type_get_type	(void) G_GNUC_CONST;

#define E_TYPE_HTML_EDITOR_SELECTION_BLOCK_FORMAT	(e_html_editor_selection_block_format_get_type())
GType e_html_editor_selection_block_format_get_type	(void) G_GNUC_CONST;

#define E_TYPE_HTML_EDITOR_SELECTION_FONT_SIZE	(e_html_editor_selection_font_size_get_type())
GType e_html_editor_selection_font_size_get_type	(void) G_GNUC_CONST;

#define E_TYPE_HTML_EDITOR_SELECTION_ALIGNMENT	(e_html_editor_selection_alignment_get_type())
GType e_html_editor_selection_alignment_get_type	(void) G_GNUC_CONST;

#define E_TYPE_HTML_EDITOR_SELECTION_GRANULARITY	(e_html_editor_selection_granularity_get_type())
GType e_html_editor_selection_granularity_get_type	(void) G_GNUC_CONST;

#define E_TYPE_HTML_EDITOR_VIEW_COMMAND	(e_html_editor_view_command_get_type())
GType e_html_editor_view_command_get_type	(void) G_GNUC_CONST;

#define E_TYPE_IMAGE_LOADING_POLICY	(e_image_loading_policy_get_type())
GType e_image_loading_policy_get_type	(void) G_GNUC_CONST;

G_END_DECLS

#endif /* E_UTIL_ENUMTYPES_H */

/* Generated data ends here */

==> evolution-devel-3.20.5-1.tar.xz: usr/include/evolution/e-util/e-util-enumtypes.h <==

/* Generated data (by glib-mkenums) */

#ifndef E_UTIL_ENUMTYPES_H
#define E_UTIL_ENUMTYPES_H

#include <glib-object.h>

G_BEGIN_DECLS

/* Enumerations from "/usr/src/ports/evolution/evolution-3.20.5-1.i686/src/evolution-3.20.5/e-util/e-util-enums.h" */

#define E_TYPE_ACTIVITY_STATE	(e_activity_state_get_type())
GType e_activity_state_get_type	(void) G_GNUC_CONST;

#define E_TYPE_AUTOMATIC_ACTION_POLICY	(e_automatic_action_policy_get_type())
GType e_automatic_action_policy_get_type	(void) G_GNUC_CONST;

#define E_TYPE_DATE_WEEKDAY	(e_date_weekday_get_type())
GType e_date_weekday_get_type	(void) G_GNUC_CONST;

#define E_TYPE_DURATION_TYPE	(e_duration_type_get_type())
GType e_duration_type_get_type	(void) G_GNUC_CONST;

#define E_TYPE_HTML_EDITOR_SELECTION_BLOCK_FORMAT	(e_html_editor_selection_block_format_get_type())
GType e_html_editor_selection_block_format_get_type	(void) G_GNUC_CONST;

#define E_TYPE_HTML_EDITOR_SELECTION_FONT_SIZE	(e_html_editor_selection_font_size_get_type())
GType e_html_editor_selection_font_size_get_type	(void) G_GNUC_CONST;

#define E_TYPE_HTML_EDITOR_SELECTION_ALIGNMENT	(e_html_editor_selection_alignment_get_type())
GType e_html_editor_selection_alignment_get_type	(void) G_GNUC_CONST;

#define E_TYPE_HTML_EDITOR_SELECTION_GRANULARITY	(e_html_editor_selection_granularity_get_type())
GType e_html_editor_selection_granularity_get_type	(void) G_GNUC_CONST;

#define E_TYPE_HTML_EDITOR_VIEW_COMMAND	(e_html_editor_view_command_get_type())
GType e_html_editor_view_command_get_type	(void) G_GNUC_CONST;

#define E_TYPE_IMAGE_LOADING_POLICY	(e_image_loading_policy_get_type())
GType e_image_loading_policy_get_type	(void) G_GNUC_CONST;

G_END_DECLS

#endif /* E_UTIL_ENUMTYPES_H */

/* Generated data ends here */
